===============================
Nameless
===============================

| |docs| |travis| |appveyor| |coveralls| |landscape| |scrutinizer|
| |version| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/python-nameless/badge/?style=flat
    :target: https://readthedocs.org/projects/python-nameless
    :alt: Documentation Status

.. |travis| image:: http://img.shields.io/travis/ionelmc/python-nameless/master.png?style=flat
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/ionelmc/python-nameless

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/ionelmc/python-nameless?branch=master
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/ionelmc/python-nameless

.. |coveralls| image:: http://img.shields.io/coveralls/ionelmc/python-nameless/master.png?style=flat
    :alt: Coverage Status
    :target: https://coveralls.io/r/ionelmc/python-nameless

.. |landscape| image:: https://landscape.io/github/ionelmc/python-nameless/master/landscape.svg?style=flat
    :target: https://landscape.io/github/ionelmc/python-nameless/master
    :alt: Code Quality Status

.. |version| image:: http://img.shields.io/pypi/v/nameless.png?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/nameless

.. |downloads| image:: http://img.shields.io/pypi/dm/nameless.png?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/nameless

.. |wheel| image:: https://pypip.in/wheel/nameless/badge.png?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/nameless

.. |supported-versions| image:: https://pypip.in/py_versions/nameless/badge.png?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/nameless

.. |supported-implementations| image:: https://pypip.in/implementation/nameless/badge.png?style=flat
    :alt: Supported imlementations
    :target: https://pypi.python.org/pypi/nameless

.. |scrutinizer| image:: https://img.shields.io/scrutinizer/g/ionelmc/python-nameless/master.png?style=flat
    :alt: Scrtinizer Status
    :target: https://scrutinizer-ci.com/g/ionelmc/python-nameless/

An example package. Replace this with a proper project description. Generated with https://github.com/ionelmc/cookiecutter-pylibrary

* Free software: BSD license

Installation
============

::

    pip install nameless

Documentation
=============

https://python-nameless.readthedocs.org/

Development
===========

To run the all tests run::

    tox
